@@ -9,8 +9,9 @@ from collections import namedtuple
 
 BlindScheduleElement = namedtuple('BlindScheduleElement', 'next_blind_change small_blind big_blind ante')
 Player = namedtuple('Player', 'bot_impl stack id')
+ROUNDS = ['Preflop', 'Flop', 'Turn', 'River']
 
-def play_tournament_table(bots, start_stack: int, use_timeout=True):
+def play_tournament_table(bots, start_stack: int, use_timeout=True, console_output = False):
     
     json_data = []
     defeated_players = []
@@ -21,15 +22,20 @@ def play_tournament_table(bots, start_stack: int, use_timeout=True):
 
     current_blinds = next(blinds_iter)
     while len(active_players) > 1:
-        print(hand_count)
 
         json_hand = {
             "hand_count": hand_count,
             "active_players": [player_to_dict(player) for player in active_players],
             "defeated_players": defeated_players
         }
+        if console_output:
+            print()
+            print("----------------------------------------------------------")
+            print("hand num: " + str(hand_count))
+            print("Players in hand: ")
+            [print(player.bot_impl.get_name() + " stack: " + str(player.stack)) for player in active_players]
 
-        rewards, json_hand_events = play_hand(active_players, get_blinds_input(current_blinds, len(active_players)), use_timeout)
+        rewards, json_hand_events = play_hand(active_players, get_blinds_input(current_blinds, len(active_players)), use_timeout, console_output)
         json_hand["hand_events"] = json_hand_events
 
         if hand_count == current_blinds.next_blind_change:
@@ -61,18 +67,33 @@ def get_blinds_input(current_blinds: BlindScheduleElement, playerCount: int) ->
 
 
 
-def play_hand(players: List[Player], blinds: List[int], use_timeut = True):
-    state, info_state, json_events = init_game(players, blinds)
+def play_hand(players: List[Player], blinds: List[int], use_timeut, console_output=False):
+    state, info_state, json_events = init_game(players, blinds, console_output)
+    if console_output:
+        print()
+        print("-- stage: " + ROUNDS[info_state.current_round] + " --")
 
     while not state.is_terminal():
         if state.is_chance_node():
             card_num = np.random.choice(state.legal_actions())
             apply_chance_action(state, info_state, json_events, card_num)
+            if console_output and len(info_state.board_cards) >= 3:
+                print()
+                print("-- stage: " + ROUNDS[info_state.current_round] + " --")
+                print("board: " + str(info_state.board_cards))
             continue
-        
+
         current_idx = state.current_player()
         action = get_player_action(players[current_idx], state, info_state, current_idx, use_timeut)
         apply_player_action(state, info_state, json_events, current_idx, action)
+        if console_output:
+            name = players[current_idx].bot_impl.get_name()
+            if action == 0:
+                print(name + " fold")
+            elif action == 1:
+                print(name + " call")
+            else:
+                print(name + " raise to " + str(action))
     
     json_events = json_events + [{
         "type": "reward", 
@@ -80,13 +101,25 @@ def play_hand(players: List[Player], blinds: List[int], use_timeut = True):
         "reward": reward, 
         "handtype": get_hand_type(list(info_state.board_cards) + list(info_state.player_hands[i])).name
     } for i, reward in enumerate(state.rewards())]
+    if console_output:
+        print()
+        for i, reward in enumerate(state.rewards()):
+            name = name = players[i].bot_impl.get_name()
+            hand = str(info_state.player_hands[i])
+            if info_state.player_infos[i].active:
+                print_str = name + hand + (" won " if reward >= 0 else " lost ") + str(reward)
+                if len(info_state.board_cards) == 5:
+                    print_str += " with a " + get_hand_type(list(info_state.board_cards) + list(info_state.player_hands[i])).name
+                print(print_str)
+            else:    
+                print(name + hand + " lost " + str(reward) + " after folding")
 
     return list(map(int, state.rewards())), json_events
 
 def get_player_action(player, state, info_state: InfoState, current_idx: int, use_timeout: bool):
     observation = info_state.to_observation(current_idx, state.legal_actions())
     try:
-        action = get_player_action_with_timeout(player, observation, 2 if use_timeout else 1000000)
+        action = get_player_action_with_timeout(player, observation, 1 if use_timeout else 1000000)
     except BaseException as e:
         print(f"Bot: '{player.bot_impl.get_name()}' caused an exception!!! Folding on their behalf.")
         print(e)
@@ -108,17 +141,6 @@ def get_player_action_with_timeout(player, obs, timeout):
         print(f"Bot: '{player.bot_impl.get_name()}' took too long to return. Folding on their behalf.")
         return 0
     return res
-    pipeRecv, pipeSend = multiprocessing.Pipe(False)
-    p = multiprocessing.Process(target=run_act_on_bot, args=(player.bot_impl, obs, pipeSend) )
-    p.start()
-    p.join(timeout)
-    if p.is_alive():
-        p.kill()
-    if not pipeRecv.poll():
-        pipeRecv.close()
-        print(f"Bot: '{player.bot_impl.get_name()}' took too long to return. Folding on their behalf.")
-        return 0
-    return pipeRecv.recv()
 
 def run_act_on_bot(bot, obs, pipe):
     pipe.send(bot.act(obs))
@@ -136,7 +158,7 @@ def apply_chance_action(state, info_state, json_events, card_num):
 
 
 
-def init_game(players, blinds):
+def init_game(players: List[Player], blinds, console_output):
     game = pyspiel.load_game("universal_poker", {
         "betting": "nolimit",
         "bettingAbstraction": "fullgame",
@@ -162,28 +184,34 @@ def init_game(players, blinds):
     json_events = []
     json_events.append({"type": "action", "player": 0, "action": blinds[0]})
     json_events.append({"type": "action", "player": 1, "action": blinds[1]})
-    json_events = json_events + [{"type": "deal", "player": int(i/2), "card": card} for i, card in enumerate(map(card_num_to_str, state.history()))]
+    cards = [card_num_to_str(c) for c in state.history()]
+    json_events = json_events + [{"type": "deal", "player": int(i/2), "card": card} for i, card in enumerate(cards)]
+
+    if console_output:
+        print()
+        print(players[0].bot_impl.get_name() + " is small blind for " + str(blinds[0]))
+        print(players[1].bot_impl.get_name() + " is big blind for " + str(blinds[1]))
+        [print(players[int(i/2)].bot_impl.get_name() + " hand: " + cards[i] + cards[i+1]) for i in range(0, len(cards), 2)]
     return state, info_state, json_events
 
 def get_blind_schedule():
-    return (BlindScheduleElement(10, 10,20,0),     
-                BlindScheduleElement(20, 15,30,0),
-                BlindScheduleElement(30, 20,40,0),
-                BlindScheduleElement(40, 25,50,0),
-                BlindScheduleElement(50, 35,70,0),
-                BlindScheduleElement(60, 45,90,0),
-                BlindScheduleElement(70, 60,120,0),
-                BlindScheduleElement(80, 75,150,0),
-                BlindScheduleElement(90, 100,200,0),
-                BlindScheduleElement(100, 125,250,0),
-                BlindScheduleElement(110, 150,300,0),
-                BlindScheduleElement(120, 200,400,0),
-                BlindScheduleElement(130, 250,500,0),
-                BlindScheduleElement(140, 350,700,0),
-                BlindScheduleElement(150, 450,900,0),
-                BlindScheduleElement(160, 600,1200,0),
-                BlindScheduleElement(170, 750,1500,0),
-                BlindScheduleElement(180, 1000,2000,0),
-                BlindScheduleElement(190, 1250,2500,0),
-                BlindScheduleElement(200, 1500,3000,0),
-                BlindScheduleElement(-1, 2000,4000,0))
\ No newline at end of file
+    return (BlindScheduleElement(20, 10,20,0),     
+            BlindScheduleElement(40, 15,30,0),
+            BlindScheduleElement(60, 20,40,0),
+            BlindScheduleElement(80, 25,50,0),
+            BlindScheduleElement(100, 30,60,0),
+            BlindScheduleElement(120, 40,80,0),
+            BlindScheduleElement(140, 55,110,0),
+            BlindScheduleElement(160, 75,150,0),
+            BlindScheduleElement(180, 100,200,0),
+            BlindScheduleElement(200, 130,260,0),
+            BlindScheduleElement(220, 165,330,0),
+            BlindScheduleElement(240, 205,410,0),
+            BlindScheduleElement(260, 250,500,0),
+            BlindScheduleElement(280, 300,600,0),
+            BlindScheduleElement(300, 375,750,0),
+            BlindScheduleElement(320, 500,1000,0),
+            BlindScheduleElement(340, 750,1500,0),
+            BlindScheduleElement(360, 1000,2000,0),
+            BlindScheduleElement(380, 1500,3000,0),
+            BlindScheduleElement(-1, 2500,5000,0))
\ No newline at end of file
